Audit Functions Used in Rules
audit_formula_functions.RdScans a directory of rule CSVs, parses the R code in them, and counts which functions are actually being called.
audit_formula_functions.RdScans a directory of rule CSVs, parses the R code in them, and counts which functions are actually being called.