Audit Recipe for Typos
audit_recipe_typos.RdScans a compiled recipe for suspicious variable names using fuzzy matching. This is the "Safety Net" when using compile_rules(allowed_vars = NULL).
audit_recipe_typos.RdScans a compiled recipe for suspicious variable names using fuzzy matching. This is the "Safety Net" when using compile_rules(allowed_vars = NULL).