Audit Test Integrity
audit_test_integrity.RdScans test files for "Mocking the System Under Test" anti-patterns. Flags test files that define their own functions instead of importing them.
audit_test_integrity.RdScans test files for "Mocking the System Under Test" anti-patterns. Flags test files that define their own functions instead of importing them.