Check for Free Variables (Implicit Dependencies)
check_free_variables.RdFinds variables used in a function that are neither Arguments nor Local Variables. These are "Free Variables" that rely on Global State (or packages).
check_free_variables.RdFinds variables used in a function that are neither Arguments nor Local Variables. These are "Free Variables" that rely on Global State (or packages).