Create Tracer Dataset (The Micro-Verse)
create_tracer_dataset.RdReads the full raw data, filters it down to a specific set of IDs, and saves mini-versions to a temporary directory.
create_tracer_dataset.RdReads the full raw data, filters it down to a specific set of IDs, and saves mini-versions to a temporary directory.