Harvest Variables
harvest_variables.RdScans a directory of configuration files (CSVs) and compiles a census of all variables being assigned to (LHS of assignments).
harvest_variables.RdScans a directory of configuration files (CSVs) and compiles a census of all variables being assigned to (LHS of assignments).