List R Files by Category
list_r_files.RdScans a directory for R scripts and separates them into 'source' (package code) or 'test' (unit tests, tinytests, specs).
Usage
list_r_files(dir_path, type = c("source", "test"))list_r_files.RdScans a directory for R scripts and separates them into 'source' (package code) or 'test' (unit tests, tinytests, specs).
list_r_files(dir_path, type = c("source", "test"))