Constructor: Audit Inventory Object
new_audit_inventory.RdValidates and creates a standardized audit inventory object. Enforces the schema to prevent silent column errors (The "Global Coupling" fix).
new_audit_inventory.RdValidates and creates a standardized audit inventory object. Enforces the schema to prevent silent column errors (The "Global Coupling" fix).