Migrate Namespace Usage
migrate_namespace.RdAutomatically refactors code to replace one package dependency with another. Useful for migrating from 'tidytable' to 'dplyr' or vice versa.
migrate_namespace.RdAutomatically refactors code to replace one package dependency with another. Useful for migrating from 'tidytable' to 'dplyr' or vice versa.