Relocate Functions to New Repositories
relocate_functions.RdReads the project inventory and copies specific functions into a new directory structure. Useful for splitting a Monolith into Micro-services.
relocate_functions.RdReads the project inventory and copies specific functions into a new directory structure. Useful for splitting a Monolith into Micro-services.